#====================================
#            defaults
#   Copyright 2011 - Nathan Osman
#
#  Keeps a list of default values
#   for configuration settings
#
#   StackApplet is released under
#         the MIT license
#====================================

__default_refresh_rate__ = 300000
__default_theme__        = "dark"
__default_accounts__     = {}
__default_port__         = 8150
__default_language__     = "" # the system default
