#===================================
#		  js_translations
#  Copyright 2011 - Nathan Osman
#
#  Makes it easy for HTML and JS
#       to be translated
#
#   StackApplet is released under
#		the MIT license
#===================================

# This dict will be filled in after the translation information
# is refreshed.
translation_keys = { }

def refresh(_):

	global translation_keys

	# Fill in the translation information
	translation_keys = { 'title': 'StackApplet Preferences',
		                 
		                 'tr_accounts'   : _('Accounts'),
		                 'tr_appearance' : _('Appearance'),
		                 'tr_system'     : _('System'),
		                 
		                 'tr_reorder_hint' : _('<strong>Note:</strong> You can reorder items by dragging them.'),
		                 'tr_account_list' : _('Here are all of the accounts registered with StackApplet:'),
		                 
		                 'tr_loading'          : _('Loading...'),
		                 'tr_account_settings' : _('Account settings:'),
		                 'tr_refresh_rate'     : _('Refresh Rate:'),
		                 
		                 'tr_every_5'  : _('Every 5 minutes'),
		                 'tr_every_8'  : _('Every 8 minutes'),
		                 'tr_every_10' : _('Every 10 minutes'),
		                 'tr_every_15' : _('Every 15 minutes'),
		                 'tr_every_20' : _('Every 20 minutes'),
		                 
		                 'tr_appearance_title' : _('Use the options below to change the appearance of StackApplet:'),
		                 'tr_icon_theme'       : _('Icon theme:'),
		                 'tr_dark'             : _(' Dark'),
		                 'tr_light'            : _(' Light'),
		                 
		                 'tr_behavior' : _('These settings affect the way StackApplet behaves:'),
		                 'tr_startup'  : _(' Load StackApplet when I log in'),
		                 'tr_mm'       : _(' Register StackApplet in the Messaging Menu'),
		                 'tr_language' : _('Language:'),
		                 
		                 'tr_footer' : _('Copyright 2011 - Nathan Osman'),
		                 
		                 'tr_enter_details'      : _('Enter the details for the new account below:'),
		                 'tr_site'               : _('Site:'),
		                 'tr_user_id'            : _('User ID:'),
		                 'tr_find_user'          : _('Find User'),
		                 'tr_find_user_hint'     : _('If you do not know your user ID, click the "find user" button.'),
		                 'tr_check_assoc'        : _('Check for associated accounts'),
		                 'tr_add_account_button' : _('Add Account'),
		                 
		                 'tr_assoc_list'   : _('The following associated accounts were found:'),
		                 'tr_check_all'    : _('check all'),
		                 'tr_uncheck_all'  : _('uncheck all'),
		                 'tr_select_assoc' : _('Please select all of the accounts you would like to add.'),
		                 'tr_add_accounts' : _('Add Accounts'),
		                 'tr_enter_disp'   : _('Please enter part of the user\'s display name and click "search."'),
		                 'tr_search'       : _('Search'),
		                 'tr_searching'    : _('Searching...'),
		                 
		                 'tr_add_account'  : _('add a new account'),
		                 'tr_no_accounts'  : _('No accounts.'),
		                 
		                 'tr_account_dialog_title'    : _('Add New Account'),
		                 'tr_associated_dialog_title' : _('Associated Accounts'),
		                 'tr_find_dialog_title'       : _('Find User:'),
		                 
		                 'tr_success_language' : _('The language was changed successfully but you will need to restart StackApplet in order to apply the new settings to the entire interface.'),
		                 
		                 'tr_error_settings'  : _('There was an error retrieving account settings.'),
		                 'tr_error_remove'    : _('There was an error removing the account.'),
		                 'tr_error_add'       : _('There was an error adding the new account.'),
		                 'tr_error_lookup'    : _('There was an error looking up your user ID.'),
		                 'tr_error_check'     : _('There was an error checking for associated accounts.'),
		                 'tr_error_swap'      : _('There was an error swapping the two items.'),
		                 'tr_error_theme'     : _('There was an error changing the theme.'),
		                 'tr_error_refresh'   : _('There was an error changing the refresh rate.'),
		                 'tr_error_language'  : _('There was an error setting the current language.'),
		                 'tr_error_add_assoc' : _('There was an error adding an account.'),
		                 'tr_error_startup'   : _('There was an error setting this application to load at startup.'),
		                 'tr_error_search'    : _('There was an error searching for users.'),
		                 'tr_error_stackauth' : _('There was an error loading the list of sites from StackAuth.')
	}
